#
# spec file for package HepMC
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with rootio

%define so_main 4
%define libmain libHepMC3-%{so_main}
%define so_search 5
%define libsearch libHepMC3search%{so_search}
Name:           HepMC
Version:        3.3.0
Release:        1.1
Summary:        An event record for High Energy Physics Monte Carlo Generators in C++
# Note: pybind11 (BSD-3-Clause) is bundled but not used because we use the system packaged pybind11
# bxzstr (bundled) uses MPL-2.0
License:        LGPL-3.0-or-later AND MPL-2.0
URL:            http://hepmc.web.cern.ch/hepmc/
Source:         http://hepmc.web.cern.ch/hepmc/releases/%{name}3-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pybind11-devel >= 2.6.0}
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  ghostscript-fonts-std
BuildRequires:  graphviz-gd
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%python_subpackages

%description
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported.

%package -n %{libmain}
Summary:        Main shared library for HepMC
License:        GPL-3.0-or-later AND MPL-2.0
Obsoletes:      libHepMC3-1 < %{version}
Provides:       %{name}3 = %{version}

%description -n %{libmain}
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported.

This package provides the main shared library for HepMC3.

%package -n %{libsearch}
Summary:        Shared library for HepMC search
License:        GPL-3.0-or-later AND MPL-2.0
Obsoletes:      libHepMC3-1 < %{version}

%description -n %{libsearch}
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported.

This package provides the shared library for HepMC3 searches.

%package devel
Summary:        Header files for HepMC
License:        GPL-3.0-or-later AND MPL-2.0
Requires:       %{libmain} = %{version}
Requires:       %{libsearch} = %{version}
Recommends:     %{name}-doc = %{version}
Provides:       %{name}3-devel = %{version}

%description devel
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported.

This package provides the source and header files required for
developing with HepMC.

%package doc
Summary:        API documentation for HepMC
License:        GPL-3.0-or-later
BuildArch:      noarch

%description doc
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported.

This package provides the API documentation for the HepMC library.

%prep
%autosetup -p1 -n %{name}3-%{version}
# Delete bundled pybind11 dir (we use system installed pybind11 headers)
rm -fr python/include

%build
%{python_expand # Necessary to run configure with all python flavors
export PYTHON=$python
mkdir ../${PYTHON}_build
cp -pr ./ ../${PYTHON}_build
pushd ../${PYTHON}_build
%cmake -DHEPMC3_ENABLE_ROOTIO:BOOL=%{?with_rootio:ON}%{!?with_rootio:OFF} \
       -DHEPMC3_BUILD_STATIC_LIBS:BOOL=OFF \
       -DHEPMC3_INSTALL_INTERFACES:BOOL=ON \
       -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/%{name}3 \
       -DHEPMC3_PYTHON_VERSIONS:STRING="%{$python_version}" \
       -DCMAKE_SKIP_RPATH:BOOL=OFF \
       -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
       -DHEPMC3_ENABLE_TEST:BOOL=ON \
%if "%{$python_provides}" == "python3" || "$python_" == "python3_"
       -DHEPMC3_BUILD_EXAMPLES:BOOL=ON \
       -DHEPMC3_BUILD_DOCS:BOOL=ON \
%else
       -DHEPMC3_BUILD_EXAMPLES:BOOL=OFF \
       -DHEPMC3_BUILD_DOCS:BOOL=OFF \
%endif
       %{nil}
%cmake_build
popd
}

%install
%{python_expand # For all python flavors
export PYTHON=$python
pushd ../${PYTHON}_build
%cmake_install
popd
}

%fdupes %{buildroot}%{_docdir}/%{name}3/

%check
%{python_expand # For all python flavors
export PYTHON=$python
pushd ../${PYTHON}_build
%ctest
popd
}

%ldconfig_scriptlets -n %{libmain}
%ldconfig_scriptlets -n %{libsearch}

%files -n %{libmain}
%license LICENCE COPYING
%{_libdir}/libHepMC3.so.%{so_main}*

%files -n %{libsearch}
%license LICENCE COPYING
%{_libdir}/libHepMC3search.so.%{so_search}*

%files -n %{name}-devel
%license LICENCE COPYING
%doc README* ChangeLog
%{_bindir}/HepMC3-config
%{_libdir}/libHepMC3.so
%{_libdir}/libHepMC3search.so
%{_includedir}/%{name}3/
%{_datadir}/%{name}3/

%files -n %{name}-doc
%doc %{_docdir}/%{name}3/

%files %{python_files}
%license LICENCE COPYING
%{python_sitearch}/pyHepMC3/
%{python_sitearch}/pyHepMC3-%{version}-py%{python_version}.egg-info
%{python_sitearch}/pyHepMC3.search-%{version}-py%{python_version}.egg-info

%changelog
* Mon Mar 24 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.3.0:
  * Update python bindings with binder 1.4.2
  * Update bxzstr to bxzstr 1.2.2 + patches
  * Explicitly return for inf-generating eta / massless rapidity
    along pz, to avoid FPE triggering.
  * Suppress cross-section/weight count-mismatch warning if only
    one cross-section.
  * Add support for reading with uproot
  * Drop Python2 support
  * Fix compilation with Python 3.13.0a1.
  * Major update of the build system, removed most of the custom
    modules.
  * Removed functions that operate on raw pointers.
- Update shared lib name in accordance with upstream so version
  bump.
- Drop HepMC-disable-doxygen-html-timestamp.patch: no longer
  needed as HTML_TIMESTAMP is not set by Doxyfile.
* Fri Oct 13 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.7:
  * Patch release to fix the problem with vertex attributes
    removal.
* Tue Sep 12 2023 Lubos Kocman <lubos.kocman@suse.com>
- Update license
  HepMC3-3.2.6/LICENSE says
  Version 3 of the GNU Lesser General Public Licence
  or any later version.
* Mon Jul 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.6:
  * Deprecated the set_cross_section function with double in
    favour of those with vector of doubles.
  * Better Doxygen documentation for code
  * Improvements in ReaderFactory that should help detect the file
    type more successfully.
  * Multiple optimizations inspired by clang-tidy
  * The Attributes are now set to be parsed after calls to
    from_string or set_value
  * API breaking changes in the search module: pass by const
    reference
  * Update python bindings
  * Modernisation of cmake
  * Fix output value of ReaderLHEF::read_event
  * Better documentation for standalone examples
  * Adds a protobuf-based HepMC3::Reader/Writer
  * Update pybind11 headers to fix python 3.11.
  * License update.
  * Make the R/W plugins transparent - the set/get functions call
    the handled object
- Adapt shared lib name to SO version bump (4->5) for
  libHepMC3search.
- License update: bundled bxzstr is MPL-2.0.
- Re-enable testing for i586.
- Make doc package noarch.
* Sat Nov  5 2022 Atri Bhattacharya <badshah400@gmail.com>
- Disable pythia interface, pythia now includes HepMC interface by
  default; this avoids a build cycle (boo#1204987,
  https://gitlab.cern.ch/hepmc/HepMC3/-/commit/9827d5fb95ece04bafbc6e09cfd792afd51f74d3).
- Add _constraints file to ensure builds do not OOM on some
  workers.
* Wed Mar  2 2022 Atri Bhattacharya <badshah400@gmail.com>
- Also Obsolete libHepMC3-1 from libHepMC3search.
* Mon Feb 21 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.5:
  * Added implementation for Relatives class that works in
    Windows.
  * (Implemented earlier) Improved MSYS2 support.
  * New interfaces for HEPEVT and update of python interface.
  * (Implemented earlier) More functions in GenEvent to deal with
    attributes.
  * (Implemented earlier) Implemented Complessed I/O with zip,
    lzma and bz2 via bxzst library.
  * Fixes to documentation of some examples.
  * Removal of unused codes and comments.
  * Fixes to Pythia8ToHepMC3.py.
  * Added Reader/Write interfaces with smart pointers.
  * Fixed #ifdefs for non-Linux system to allow the usage of
    Reader/Writer plugins.
  * Added MT reader.
  * Remove outdated interfaces to MCEGs.
- Add HepMC-disable-doxygen-html-timestamp.patch: Disable
  timestamps in doxygen generated HTML footers to make builds
  reproducible.
- Split libraries into separate shared lib packages.
- Build for all supported python flavours.
- Fix shalred lib versioning and obsolete libHepMC3-1 from
  libHepMC3-3 since previous lib was incorrectly named.
- Delete bundled pybind11 and use system package; add
  BuildRequires: python-pybind11-devel >= 2.6.0.
* Tue Dec  7 2021 Atri Bhattacharya <badshah400@gmail.com>
- Temporarily disable tests for i586 until tolerance issues are
  sorted out.
* Sat Nov 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.4:
  * Minor fixes to the CMake configuration of examples.
  * Minor fixes in Pythia6 interface.
  * Bugfix for HI output in WiterAsciiHepMC2.
  * Speed optimizations for ReaderAsciiHepMC2.
  * Deprecate Pythia8, MC-TESTER, Taoulapp and Photospp
    interfaces, as these were picked-up by the upstream.
  * Bugfix: avoid cretion of empty attributes in
    ReaderAsciiHepMC2. Thanks to Pavel Demin for a hint.
  * Removal of trailing empty lines by Mattias Ellert.
  * Multiple fixes to style and printf by Mattias Ellert.
  * Fix WriterAscii* to avoid problems with memory tests on
    aarch64. Thanks to Mattias Ellert for reporting.
  * Fix buffer overflow in WritterAscii/WriterAsciiHepMC2. Thanks
    for Fabian Klimpel for help with debug.
  * Enable reading of multiple run info objects from ASCII files.
  * Fixes to the tests.
  * Drop cmake2 support
  * Update cmake so the c++ standard is deduced from the ROOT
    configuration if ROOT is used. Otherwise c++11 is used.
  * Fix a bug in GenCrossSection: acces to non-existing vector
    element in to_string() function. Happened for incomplete
    objects.
  * Fixed formating.
  * Added compiler flags to reduce the amount of warnings.
  * Fixed a bug in Tauola test, which was not reading proper
    config.
  * Streamlined cmake for PGI.
  * Fixed some tests to make them return non 0 in case of
    problems.
  * Updated CI.
  * Reduce debug-printout verbosity in ReaderFactory format
    autodetection.
  * Added uproot-based reader to examples.
  * Fixed cmake configuration to allow multiple Python versions.
  * Fixes of compilation warnings by Mattias Ellert.
* Sun Mar 14 2021 Atri Bhattacharya <badshah400@gmail.com>
- Move doc to HepMC3 named dir to avoid clash with HepMC2.
- Provide HepMC3-* where appropriate.
* Thu Dec 17 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.3:
  * Documentation and copyright years were updated.
  * Python bindings were regenerated with binder 1.1.0 and the
    pybind11 copy updated to 2.6.0.
  * The #ifdefs around the functions that had to be excluded from
    bindings but binder 1.0.0 was not doing that were removed.
  * A python test with attributes was added.
  * ReaderLHEF was fixed for to treat correctly more comaplicated
    input.
  * Included updates to many python scripts.
  * Included updates to CMake scripts.
- Run tests; need to pass CMAKE_SKIP_RPATH=OFF to cmake to fix
  rpath handling in Leap 15.2 (and doesn't hurt generally).
* Tue Jul 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.2:
  * Fixed treatment of the weights in case of different number of
    weights and weight names.
  * Fixed WriterAsciiHepMC2 option for separate flows.
  * Improved treatment of python installation.
  * Split the sources of python bindings into smaller files to
    optimize compilation.
  * Improved cmake configuration for special cases, e.g. old
    cmake, no ROOT, some compilers, etc. Added more error
    handling.
  * Fixed compilation of the search module with Clang.
  * Added an example for search module.
  * Fixed the HepMC2 output for events without weights.
  * Fixed the signal vertex ID for HepMC2 output.
  * Added an interface for HepMC2 (in-memory-conversion).
  * Added functions to search module: search for relatives
    (particle or vertex)->(particle or vertex) in different
    combinations.
  * The previous point bumps .so version of the libHepMC3search to
    4.
  * Improved the configuration of Pythia8 for tests (minimal
    version requirement).
  * Fixed compatibility of ROOT trees written with HePMC3.0 and
    removed the typedefs in the dictionaries.
- Drop HepMC-type-mismatch-error.patch: incorporated upstream.
* Mon Jun  8 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add HepMC-type-mismatch-error.patch: Fix type mismatch between
  function definition and function call flagged by GCC 10.
- Use autosetup to setup build dir and automatically apply patch.
* Wed Apr 22 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update Licensing:
  * Main License has been changed to GPL-3.0-or-later.
  * Python bindings licensed under the BSD-3-Clause.
- Package the appropriate License file for python-%%{name} package.
* Sat Apr  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.1:
  * Bugfix release.
  * Explicit usage of namespaces.
  * Disallow empty lines for the attribute names.
  * Added an option for explicit selection of packages for
    testing.
  * Adjustments in the interfaces of Tauola/Photos/mc-tester as a
    part of preparation to the new releases of these libraries
  * Experimental support for Python modulescompilation with pypy.
  * Bugfix in VectorString attribute.
  * Improvement in the attribute parsing.
  * Added an option to handle Python 3.9.
  * Implemented special treatment of some broken HePMC2 events.
- Update to version 3.2.0:
  * First release with Python bindings.
  * Added ReaderPlugin and WriterPlugin and macros to declare
    plugins.
  * Fixed GenCrossSection for the case of multiple
    cross-sections.
  * Removed Error class.
  * Removed ReaderHEPEVT::read_hepevt_particle(int i, bool
    iflong=true), ReaderHEPEVT::read_event(GenEvent &evt, bool
    iflong).
  * Removed ReaderHEPEVT::get_vertices_positions_present and
    ReaderHEPEVT::set_vertices_positions_present. The
    functionality above is implemented now Reader::set_options,
    Reader::get_options.
  * Fixed GenEvent::weight_names(). Now it should be called w/o
    arguments.
  * Added set_options, get_options to I/O classes for fine control
    of I/O.
  * The standard Selector members from Selector (e.g.
    Selector::MASS) were moved into a new class StandardSelector.
  * Added HEPMC3_ prefix to DEBUG, ERROR, WARNING  macros.
  * Added Reader::skip(int &) for fast forwarding of input.
  * Added to LHEF::Writer wrapper functions that can be used in
    Python.
  * use delete/override for class members.
- Build python3 bindings and package them in a new subpackage
  python3-HepMC; introduces BuildRequires on python3 and
  python3-devel.
- Build docs and examples by passing the appropriate options to
  cmake and package them in a -doc subpackage; drop commands used
  to build doc separately.
- Use %%bcond_with/%%bcond_without to enable pythia and disable
  rootio respectively.
- Add BuildRequires: pkgconfig(zlib) to enable linking against
  zlib.
- Package LICENCE and COPYING files using %%license.
* Sun Mar 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Disable setting rpaths on installed libs.
* Wed Jan  8 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.2:
  * Add GenParticle::abs_pid() to match FourVector::abs_eta(),
    abs_rap().
  * Add FourVector component-setting functions in HepMC method
    naming convention; deprecate old camelCase ones.
  * Bugfix release. Fixed some typos and minor bugs.
  * Fixed name of ROOT dictionary
  * Added more standard attributes
  * Extended documentation for doxygen
  * Added stremer output to Reader/Writer classes
  * Added procedures for boost, rotation and reflection to
    GenEvent
  * Added operators for printing events, particles, etc.
  * Added example with reading of compressed file and more tests
- Run fdupes on full docdir to link even more duplicated files.
* Wed May  1 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.1:
  * Improved treatment of events with cycles.
  * Improved documentation and examples.
- Changes from version 3.1.0:
  * Renaming the namespace, header directory and library name to
    HepMC3
  * SmartPointer is repaced with shared_ptr from C++11, so C++11
    is always required now
  * Split library into HepMC3(core) and HepMC3search (search
    engine)
  * New Search engine with highly abstract search capabilities
  * New readers and writers: WriterAsciiHepMC2, ReaderLHEF
  * Ascii files now have own string in header: Asciiv3
  * Deduction of input file format in ReaderFactory
  * Improved consistency of interface
  * Removal of most deprecated functions and  multiple bugfixes
  * Implemented test suite
  * Improved examples and documentation
- Drop sover.diff: so versioning added by upstream.
- Update Source url in keeping with upstream name changes.
- Adapt to name changes (HepMC -> HepMC3) in spec file wherever
  appropriate.
- Use %%%%cmake_build for building and parallel jobs when building
  documentation.
- Package new library libHepMC3search.
- New BuildRequires: graphviz-gd and ghostscript-fonts-std needed
  to generate docs, gcc-fortran needed for library.
* Wed Aug  9 2017 jengelh@inai.de
- Reapply shared library guidelines.
- Add sover.diff to force shlib versioning.
- Slightly trim description for length.
* Sat Aug  5 2017 badshah400@gmail.com
- Update to version 3.0.0:
  + See list of changes from:
    https://gitlab.cern.ch/hepmc/HepMC3/blob/3.0.0/ChangeLog.
- Drop shared library subpackage; there is no numbered shared lib
  any more. Package everything into the devel package.
- Use cmake macros for build and install.
- Drop unused cmake options.
- Build and install doxygen documentation.
- Manually install examples to docdir, running fdupes to weed out
  duplicated files.
- Update URL and Source URL for new upstream links.
- Updated file-list.
* Fri Dec  6 2013 badshah400@gmail.com
- Initial version
